#!/bin/bash

# This script will build your TASTE system.

# You must check it before running it: it may need to be adapted to your context:
# 1) You may need to fix some paths and filenames (path to interface/deployment views)
# 2) You may need to specify additional paths for the compiler to find .h file
#    (e.g. "export C_INCLUDE_PATH=/usr/include/xenomai/analogy/:$C_INCLUDE_PATH")
# 3) You may need to link with pre-built libraries, using the -l option
#    (e.g. -l /usr/lib/libanalogy.a,/usr/lib/librtdm.a)
# 4) You may need to change the runtime (add -p flag to select PolyORB-HI-C)
# etc.

# Note: TASTE will not overwrite your changes - if you need to update some  parts
#       you will have to merge the changes with the newly-created "build-script.new.sh" file.

if [ -z "$DEPLOYMENTVIEW" ]
then
    DEPLOYMENTVIEW=DeploymentView.aadl
fi

SKELS="/home/assert/work/ProducerConsumerPUS/transformation/scm_examples/src/"

cd "$SKELS"
rm -f producer_inst.zip
zip producer_inst producer_inst/*
rm -f consumer_inst.zip
zip consumer_inst consumer_inst/*
rm -f groundpacketservice.zip
zip groundpacketservice groundpacketservice/*
rm -f psethernetproxy.zip
zip psethernetproxy psethernetproxy/*
rm -f psethernettxtable.zip
zip psethernettxtable psethernettxtable/*
rm -f psrxdispatching.zip
zip psrxdispatching psrxdispatching/*
rm -f pstxmanagement.zip
zip pstxmanagement pstxmanagement/*
rm -f psrxtable.zip
zip psrxtable psrxtable/*
rm -f pstmroutingtable.zip
zip pstmroutingtable pstmroutingtable/*
rm -f dhctctables.zip
zip dhctctables dhctctables/*
rm -f dhctcpublishing.zip
zip dhctcpublishing dhctcpublishing/*
rm -f dhctcverification.zip
zip dhctcverification dhctcverification/*
rm -f dhctcdispatcher.zip
zip dhctcdispatcher dhctcdispatcher/*
rm -f dhctmreceiver.zip
zip dhctmreceiver dhctmreceiver/*
rm -f reportingtmpublishing.zip
zip reportingtmpublishing reportingtmpublishing/*
rm -f reportingtmtable.zip
zip reportingtmtable reportingtmtable/*
rm -f reportingtmdispatching.zip
zip reportingtmdispatching reportingtmdispatching/*
rm -f reportinggeneratetm.zip
zip reportinggeneratetm reportinggeneratetm/*
rm -f reportingcontroleventreport.zip
zip reportingcontroleventreport reportingcontroleventreport/*
rm -f reportingeventreportgeneration.zip
zip reportingeventreportgeneration reportingeventreportgeneration/*
rm -f commandingtcpublishing.zip
zip commandingtcpublishing commandingtcpublishing/*
rm -f commandingtctable.zip
zip commandingtctable commandingtctable/*
rm -f commandingtcdispatcher.zip
zip commandingtcdispatcher commandingtcdispatcher/*
rm -f commandingprocesscommand.zip
zip commandingprocesscommand commandingprocesscommand/*
rm -f commandingcommandverificationmanager.zip
zip commandingcommandverificationmanager commandingcommandverificationmanager/*
rm -f commandingcommandfunctionality.zip
zip commandingcommandfunctionality commandingcommandfunctionality/*
rm -f commandingsystemmanagement.zip
zip commandingsystemmanagement commandingsystemmanagement/*
rm -f monitoringtcpublishing.zip
zip monitoringtcpublishing monitoringtcpublishing/*
rm -f monitoringtctable.zip
zip monitoringtctable monitoringtctable/*
rm -f monitoringtcdispatching.zip
zip monitoringtcdispatching monitoringtcdispatching/*
rm -f monitoringprocesscommand.zip
zip monitoringprocesscommand monitoringprocesscommand/*
rm -f monitoringcontrol.zip
zip monitoringcontrol monitoringcontrol/*
rm -f monitoringmonitor.zip
zip monitoringmonitor monitoringmonitor/*
rm -f monitoringdataacquisition.zip
zip monitoringdataacquisition monitoringdataacquisition/*
rm -f timeprocesstc.zip
zip timeprocesstc timeprocesstc/*
rm -f timereportrate.zip
zip timereportrate timereportrate/*
rm -f obtimesatellitetime.zip
zip obtimesatellitetime obtimesatellitetime/*
cd "$OLDPWD"

[ ! -z "$CLEANUP" ] && rm -rf binary

echo 'Building the system with the Ada runtime (add -p in the build script to replace with C)'
assert-builder-ocarina.py \
	-f \
	-g \
	--aadlv2 \
	--keep-case \
	--interfaceView InterfaceView.aadl \
	--deploymentView "$DEPLOYMENTVIEW" \
	-o binary \
	--subC producer_inst:"$SKELS"/producer_inst.zip \
	--subC consumer_inst:"$SKELS"/consumer_inst.zip \
	--subAda groundpacketservice:"$SKELS"/groundpacketservice.zip \
	--subAda psethernetproxy:"$SKELS"/psethernetproxy.zip \
	--subAda psethernettxtable:"$SKELS"/psethernettxtable.zip \
	--subAda psrxdispatching:"$SKELS"/psrxdispatching.zip \
	--subAda pstxmanagement:"$SKELS"/pstxmanagement.zip \
	--subAda psrxtable:"$SKELS"/psrxtable.zip \
	--subAda pstmroutingtable:"$SKELS"/pstmroutingtable.zip \
	--subAda dhctctables:"$SKELS"/dhctctables.zip \
	--subAda dhctcpublishing:"$SKELS"/dhctcpublishing.zip \
	--subAda dhctcverification:"$SKELS"/dhctcverification.zip \
	--subAda dhctcdispatcher:"$SKELS"/dhctcdispatcher.zip \
	--subAda dhctmreceiver:"$SKELS"/dhctmreceiver.zip \
	--subAda reportingtmpublishing:"$SKELS"/reportingtmpublishing.zip \
	--subAda reportingtmtable:"$SKELS"/reportingtmtable.zip \
	--subAda reportingtmdispatching:"$SKELS"/reportingtmdispatching.zip \
	--subAda reportinggeneratetm:"$SKELS"/reportinggeneratetm.zip \
	--subAda reportingcontroleventreport:"$SKELS"/reportingcontroleventreport.zip \
	--subAda reportingeventreportgeneration:"$SKELS"/reportingeventreportgeneration.zip \
	--subAda commandingtcpublishing:"$SKELS"/commandingtcpublishing.zip \
	--subAda commandingtctable:"$SKELS"/commandingtctable.zip \
	--subAda commandingtcdispatcher:"$SKELS"/commandingtcdispatcher.zip \
	--subAda commandingprocesscommand:"$SKELS"/commandingprocesscommand.zip \
	--subAda commandingcommandverificationmanager:"$SKELS"/commandingcommandverificationmanager.zip \
	--subAda commandingcommandfunctionality:"$SKELS"/commandingcommandfunctionality.zip \
	--subAda commandingsystemmanagement:"$SKELS"/commandingsystemmanagement.zip \
	--subAda monitoringtcpublishing:"$SKELS"/monitoringtcpublishing.zip \
	--subAda monitoringtctable:"$SKELS"/monitoringtctable.zip \
	--subAda monitoringtcdispatching:"$SKELS"/monitoringtcdispatching.zip \
	--subAda monitoringprocesscommand:"$SKELS"/monitoringprocesscommand.zip \
	--subAda monitoringcontrol:"$SKELS"/monitoringcontrol.zip \
	--subAda monitoringmonitor:"$SKELS"/monitoringmonitor.zip \
	--subAda monitoringdataacquisition:"$SKELS"/monitoringdataacquisition.zip \
	--subAda timeprocesstc:"$SKELS"/timeprocesstc.zip \
	--subAda timereportrate:"$SKELS"/timereportrate.zip \
	--subAda obtimesatellitetime:"$SKELS"/obtimesatellitetime.zip